@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2019 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2019, 2020 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -14,6 +14,7 @@
 
 #include "TransformationManager.h"
 
+#include <iostream>
 #include <sstream>
 
 #include "clang/Basic/Builtins.h"
@@ -26,6 +27,7 @@
 
 #include "Transformation.h"
 
+using namespace std;
 using namespace clang;
 
 int TransformationManager::ErrorInvalidCounter = 1;
@@ -286,6 +288,7 @@ bool TransformationManager::doTransformation(std::string &ErrorMsg, int &ErrorCo
   Diag.setSuppressAllDiagnostics(true);
   Diag.setIgnoreAllWarnings(true);
 
+  CurrentTransformationImpl->setWarnOnCounterOutOfBounds(WarnOnCounterOutOfBounds);
   CurrentTransformationImpl->setQueryInstanceFlag(QueryInstanceOnly);
   CurrentTransformationImpl->setTransformationCounter(TransformationCounter);
   if (ToCounter > 0) {
@@ -396,10 +399,18 @@ void TransformationManager::outputNumTransformationInstances()
 {
   int NumInstances = 
     CurrentTransformationImpl->getNumTransformationInstances();
-  llvm::outs() << "Available transformation instances: " 
+  llvm::outs() << "Available transformation instances: "
                << NumInstances << "\n";
 }
 
+void TransformationManager::outputNumTransformationInstancesToStderr()
+{
+  int NumInstances =
+    CurrentTransformationImpl->getNumTransformationInstances();
+  cerr  << "Available transformation instances: "
+        << NumInstances << "\n";
+}
+
 TransformationManager::TransformationManager()
   : CurrentTransformationImpl(NULL),
     TransformationCounter(-1),
@@ -414,7 +425,9 @@ TransformationManager::TransformationManager()
     CheckReference(false),
     ReferenceValue(""),
     SetCXXStandard(false),
-    CXXStandard("")
+    CXXStandard(""),
+    WarnOnCounterOutOfBounds(false),
+    ReportInstancesCount(false)
 {
   // Nothing to do
 }
