@@ -1,6 +1,3 @@
-import shutil
-import subprocess
-
 from cvise.passes.abstract import AbstractPass, PassResult
 from cvise.utils.error import UnknownArgumentError
 
@@ -31,7 +28,7 @@ class IndentPass(AbstractPass):
         elif self.arg == "final":
             cmd.append(test_case)
         else:
-            raise UnknownArgumentError()
+            raise UnknownArgumentError(self.__class__.__name__, self.arg)
 
         _, _, returncode = process_event_notifier.run_process(cmd)
         if returncode != 0:
