@@ -1,6 +1,4 @@
-import logging
 import shutil
-import subprocess
 import tempfile
 import re
 import os
